@@ -5,7 +5,8 @@ import (
 	"os"
 	"strings"
 
-	"github.com/hairyhenderson/gomplate/v3/data"
+	"github.com/hairyhenderson/gomplate/v4/internal/datafs"
+	"github.com/hairyhenderson/gomplate/v4/internal/parsers"
 )
 
 // context for templates
@@ -22,17 +23,27 @@ func (c *tmplctx) Env() map[string]string {
 }
 
 // createTmplContext reads the datasources for the given aliases
-func createTmplContext(_ context.Context, aliases []string, d *data.Data) (interface{}, error) {
-	var err error
+func createTmplContext(
+	ctx context.Context, aliases []string,
+	sr datafs.DataSourceReader,
+) (interface{}, error) {
 	tctx := &tmplctx{}
 	for _, a := range aliases {
-		if a == "." {
-			return d.Datasource(a)
-		}
-		(*tctx)[a], err = d.Datasource(a)
+		ct, b, err := sr.ReadSource(ctx, a)
 		if err != nil {
 			return nil, err
 		}
+
+		content, err := parsers.ParseData(ct, string(b))
+		if err != nil {
+			return nil, err
+		}
+
+		if a == "." {
+			return content, nil
+		}
+
+		(*tctx)[a] = content
 	}
 	return tctx, nil
 }
