@@ -4,6 +4,7 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func must(r interface{}, err error) interface{} {
@@ -15,12 +16,18 @@ func must(r interface{}, err error) interface{} {
 
 func TestLookupIP(t *testing.T) {
 	assert.Equal(t, "127.0.0.1", must(LookupIP("localhost")))
-	assert.Equal(t, "93.184.216.34", must(LookupIP("example.com")))
+	assert.Equal(t, "198.41.0.4", must(LookupIP("a.root-servers.net")))
 }
 
 func TestLookupIPs(t *testing.T) {
 	assert.Equal(t, []string{"127.0.0.1"}, must(LookupIPs("localhost")))
-	assert.Equal(t, []string{"93.184.216.34"}, must(LookupIPs("example.com")))
+	assert.ElementsMatch(t, []string{"1.1.1.1", "1.0.0.1"}, must(LookupIPs("one.one.one.one")))
+}
+
+func BenchmarkLookupIPs(b *testing.B) {
+	for i := 0; i < b.N; i++ {
+		must(LookupIPs("localhost"))
+	}
 }
 
 func TestLookupTXT(t *testing.T) {
@@ -33,6 +40,6 @@ func TestLookupCNAME(t *testing.T) {
 
 func TestLookupSRV(t *testing.T) {
 	srv, err := LookupSRV("_sip._udp.sip.voice.google.com")
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, uint16(5060), srv.Port)
 }
