@@ -11,41 +11,50 @@ import (
 	"testing/fstest"
 
 	"github.com/hairyhenderson/go-fsimpl"
-	"github.com/hairyhenderson/gomplate/v3/data"
+	"github.com/hairyhenderson/gomplate/v4/internal/datafs"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestRenderTemplate(t *testing.T) {
+	wd, _ := os.Getwd()
+	t.Cleanup(func() {
+		_ = os.Chdir(wd)
+	})
+	_ = os.Chdir("/")
+
 	fsys := fstest.MapFS{}
-	ctx := ContextWithFSProvider(context.Background(),
-		fsimpl.WrappedFSProvider(fsys, "mem"))
+	fsp := fsimpl.NewMux()
+	fsp.Add(datafs.EnvFS)
+	fsp.Add(datafs.StdinFS)
+	fsp.Add(datafs.WrappedFSProvider(fsys, "mem", ""))
+	ctx := datafs.ContextWithFSProvider(context.Background(), fsp)
 
 	// no options - built-in function
-	tr := NewRenderer(Options{})
+	tr := NewRenderer(RenderOptions{})
 	out := &bytes.Buffer{}
 	err := tr.Render(ctx, "test", "{{ `hello world` | toUpper }}", out)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "HELLO WORLD", out.String())
 
 	// with datasource and context
 	hu, _ := url.Parse("stdin:")
 	wu, _ := url.Parse("env:WORLD")
 
-	os.Setenv("WORLD", "world")
-	defer os.Unsetenv("WORLD")
+	t.Setenv("WORLD", "world")
 
-	tr = NewRenderer(Options{
-		Context: map[string]Datasource{
+	tr = NewRenderer(RenderOptions{
+		Context: map[string]DataSource{
 			"hi": {URL: hu},
 		},
-		Datasources: map[string]Datasource{
+		Datasources: map[string]DataSource{
 			"world": {URL: wu},
 		},
 	})
-	ctx = data.ContextWithStdin(ctx, strings.NewReader("hello"))
+	ctx = datafs.ContextWithStdin(ctx, strings.NewReader("hello"))
 	out = &bytes.Buffer{}
 	err = tr.Render(ctx, "test", `{{ .hi | toUpper }} {{ (ds "world") | toUpper }}`, out)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "HELLO WORLD", out.String())
 
 	// with a nested template
@@ -53,8 +62,8 @@ func TestRenderTemplate(t *testing.T) {
 	fsys["nested.tmpl"] = &fstest.MapFile{Data: []byte(
 		`<< . | toUpper >>`)}
 
-	tr = NewRenderer(Options{
-		Templates: map[string]Datasource{
+	tr = NewRenderer(RenderOptions{
+		Templates: map[string]DataSource{
 			"nested": {URL: nu},
 		},
 		LDelim: "<<",
@@ -62,11 +71,11 @@ func TestRenderTemplate(t *testing.T) {
 	})
 	out = &bytes.Buffer{}
 	err = tr.Render(ctx, "test", `<< template "nested" "hello" >>`, out)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "HELLO", out.String())
 
 	// errors contain the template name
-	tr = NewRenderer(Options{})
+	tr = NewRenderer(RenderOptions{})
 	err = tr.Render(ctx, "foo", `{{ bogus }}`, &bytes.Buffer{})
 	assert.ErrorContains(t, err, "template: foo:")
 }
@@ -77,7 +86,7 @@ func ExampleRenderer() {
 	ctx := context.Background()
 
 	// create a new template renderer
-	tr := NewRenderer(Options{})
+	tr := NewRenderer(RenderOptions{})
 
 	// render a template to stdout
 	err := tr.Render(ctx, "mytemplate",
@@ -95,7 +104,7 @@ func ExampleRenderer_manyTemplates() {
 	ctx := context.Background()
 
 	// create a new template renderer
-	tr := NewRenderer(Options{})
+	tr := NewRenderer(RenderOptions{})
 
 	templates := []Template{
 		{
@@ -134,19 +143,21 @@ func ExampleRenderer_manyTemplates() {
 func ExampleRenderer_datasources() {
 	ctx := context.Background()
 
-	// a datasource that retrieves JSON from a maritime registry dataset
-	u, _ := url.Parse("https://www.econdb.com/maritime/vessel/9437/")
-	tr := NewRenderer(Options{
-		Context: map[string]Datasource{
-			"vessel": {URL: u},
+	// a datasource that retrieves JSON from a public API
+	u, _ := url.Parse("https://ipinfo.io/1.1.1.1")
+	tr := NewRenderer(RenderOptions{
+		Context: map[string]DataSource{
+			"info": {URL: u},
 		},
 	})
 
 	err := tr.Render(ctx, "jsontest",
-		`{{"\U0001F6A2"}} The {{ .vessel.data.Name }}'s call sign is {{ .vessel.data.Callsign }}, `+
-			`and it has a draught of {{ .vessel.data.Draught }}.`,
+		`{{"\U0001F30E"}} {{ .info.hostname }} is served by {{ .info.org }}`,
 		os.Stdout)
 	if err != nil {
 		panic(err)
 	}
+
+	// Output:
+	// 🌎 one.one.one.one is served by AS13335 Cloudflare, Inc.
 }
